![image](http://f.cl.ly/items/1F0y2N1W3V1M1v2m2k1C/wdtuts-logo.png)

#SEO Checklist

Thank you for downloading the SEO checklist. Learn it by heart or simply print it out for your next SEO project.

You can consult the [complete SEO session](http://webdesign.tutsplus.com/sessions/seo-fundamentals-for-web-designers/) on Webdesigntuts+ for future reference.

***

#On-site SEO
These SEO techniques can influence the entire website.

###Accessibility
- **Page access**: If a search engine can't reach a page, it's impossible to have it indexed. Make sure that the robots.txt file or robots meta tag isn't accidentally blocking important pages.

- **Block inappropriate pages**: On the other hand: some pages should not be indexed, for example incomplete pages or confidential pages. Block them via the robots.txt file or robots meta tag.

- **Pagination**: help search engines handle pagination by implementing the `rel="next"` and `rel="prev"` tag.

- **Redirects**: use 301-redirects instead of 302. 

- **404 errors**: try to reduce the amount of 404 errors to a minimum.

- **Site speed**: site speed has become a ranking factor. Faster is better. Use Google Page Speed to check the loading time of your pages.

- **Mobile accessibility**: is your site accessible for mobile devices? Google recommends a responsive design.

- **Duplicate content**: check for duplicate content in Google Webmaster tools, via the site: search command or via site crawling software. Duplicate content issues can be solved via a 301-redirect, the `rel="canonical"` tag, meta robots tag, URL rewriting or Google Webmaster Tools. 

###URL Structure
- **www or non-www**: Choose one and make sure the internal and inbound links use the same format. Use Google Webmaster Tools to set the preferred version. Automatic URL rewriting is also possible.

- **Domain extension**: Local businesses might want to consider choosing a country-specific domain extension for better ranking. 

- **Subdomain or subfolder**: Subdomains are often seen by Google as separate domains, so it's best to use subfolders. If you have several, non-related products you can still opt for a subdomain though.

- **Descriptive URLs**: use a descriptive page name instead of a random number of words and letters. The same goes for subfolders. 

- **Hyphens**: use hyphens to split words in a URL. 

- **URL parameters**: you can help Google handle URL parameters via Google Webmaster tools.

###Sitemaps

- **HTML sitemap**: a HTML sitemap is not only useful for visitors, but also for search engines. It helps them understand your site architecture. 

- **XML sitemap**: this sitemap is only visible for search engines. XML sitemaps allow you to add metadata which can be used to provide additional information about the content of each page. An XML sitemap can contain a maximum of 50,000 links.

- **Image sitemap**: The Image Sitemap can help your images show up in Google Image Search results and get you some extra visitors. 

- **Video sitemap**: a video sitemap can help with the creation of rich snippets for your page. 

***

#On-page SEO
On-page SEO techniques optimize a single page for search engines.

###Keyword

- **Single keyword per page**: Make sure every page targets a single keyword. 

- **Keyword research**: ranking for the correct keywords is very important. Do some research and see which keyword has the highest traffic potential and the least amount of competition. Balance these two factors. 

- **Keyword in URL**: use the keyword in the URL (page name).

- **Keyword in title**: use the keyword in the title of the page, preferably in the beginning. This is an important indicator for search engines to categorise a page. 

- **Keyword in headings**: use the keyword in one or more headings (h1, h2, h3...). The H1 tag should only be used once on a page and should be used for the title.

- **Keyword in content**: it's impossible to write about a topic without using the keyword. Use the keyword, including variations and synonyms throughout the text. Try to use it in the first paragraph too. 

###Content

- **Title**: max. 70 characters long.

- **Unique value**: content that provides a unique value attracts link naturally. 

- **Content type**: choosing a different content type, e.g. infographic, comic, quiz... can help you attract links. 

- **Crawlable**: Search engines have difficulties crawling certain content types, for example images or flash content. A combination of HTML, CSS and webfonts can be used to solve certain crawlability problems. 

- **Language targeting**: inform search engines about a translated page by using the `rel="alternate" hreflang="x"` annotation.

- **Freshness**: search engines like new content. Regularly posting or updating pages is recommended.

- **Content length**: content length is correlated with rankings. Try to aim for at least 300 words.


###Images

- **File name**: choose a descriptive file name instead of random words and numbers. 

- **Alt-tag**: don't forget to add an alt-tag with a short description of the image. 

- **Size**: keep your images as small as possible to improve page load times.

###Display in SERP

- **Meta description**: change the description of a page in the SERPs by adding a meta-description tag. A good description convinces surfers to click on the link. Don't forget to use keywords because they appear in bold. 

- **Structured data**: add structured data to your page that can be used to generate rich snippets. Rich snippets can vastly improve the CTR of your pages. Structured data can be added via microdata, RFDa or microformats. 

- **Authorship information**: add authorship information to your pages. AuthorRank is a relatively new ranking factor.

###Social Snippets

- **Thumbnail**: choose an eye-catching thumbnail that's at least 200 x 200 pixels. 

- **Title**: the title acts as an anchor text for your social snippet. 

- **URL**: the URL of the underlying page. Don't forget to tag your URL using Google's URL builder for additional information in Google Analytics. 

- **Description**: a short description of the content. You can use the meta-description for this. 

- **Twitter card**: Twitter Cards use the Open Graph tags, supplemented with several Twitter-specific tags. 

###Local Search

- **Local optimization**: optimize your page as you would do for any other keyword. Use the location (for example Palo Alto) in the page title, url and content. 

- **Structured data**: location information can also be added via structured data. 

- **Multiple locations**: if you have a chain of businesses, create a unique page with a separate URL for each location. 

- **Google+**: create a Google+ Local page for your business.

- **Local listing**: get links from local listings (YellowPages, Foursquare, Yelp...) to improve your visibility for local search queries. 

***

#Off-site SEO
Techniques that are beyond our own website.

- **Inbound links**: check the number of inbound links. 

- **Authority**: links from sites with a high domain authority are more valuable.

- **Anchor text**: the anchor text is the text that is used to link to your site. Keywords in an anchor text are very useful, but don't overdo this. Make sure your link profile looks natural. 

- **Diversity**: try to gain links from multiple, relevant domains instead of only a handful of sites.

- **Nofollow**: inbound links that use the `rel="nofollow"` tag passe no PageRank 

- **Bad links**: links from spammy sites can hurt your rankings. Contact the webmaster to remove them or use the Disavow Tool. 

